@@ -1,7 +1,7 @@
 /**
  This file is part of Kig, a KDE program for Interactive Geometry...
- Copyright (C) 2002  Dominique Devriese
- 
+ Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
+
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
@@ -11,7 +11,7 @@
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
- 
+
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
@@ -21,16 +21,16 @@
 
 #include "coordinate_system.h"
 
+#include "i18n.h"
+
 #include <qpainter.h>
 #include <qregexp.h>
+#include <kdebug.h>
 
 #include <cmath>
 
-// this is in math.h, but include cmath doesn't work nicely for me..
-// #include <cmath>
-// extern "C" {
-// double fabs(double);
-// };
+using std::floor;
+using std::pow;
 
 EuclideanCoords::EuclideanCoords()
 {
@@ -43,12 +43,13 @@ QString EuclideanCoords::fromScreen(const Coordinate& p) const
 
 Coordinate EuclideanCoords::toScreen(const QString& s, bool& ok) const
 {
-  QRegExp r("\\(([^,]+),([^\\)]+)\\)");
-  ok = r.match(s);
+  QRegExp r("^\\(([^,]+),([^\\)]+)\\)$");
+  ok = ( r.search(s) == 0 );
+  kdDebug() << "hoereu!!" << endl;
   if (ok)
-    {
-      return Coordinate(r.cap(1).toDouble(&ok), r.cap(2).toDouble(&ok));
-    }
+  {
+    return Coordinate(r.cap(1).toDouble(&ok), r.cap(2).toDouble(&ok));
+  }
   else return Coordinate();
 };
 
@@ -81,7 +82,7 @@ void EuclideanCoords::drawGrid( KigPainter& p ) const
   for ( int i = iMinY; i <= iMaxY; ++i )
     p.drawSegment( Coordinate( dMinX, i * vInterval ),
 		   Coordinate( dMaxX, i * vInterval ) );
-  
+
   /****** the axes ******/
   p.setPen( QPen( Qt::gray, 1, Qt::SolidLine ) );
   // x axis
@@ -97,26 +98,26 @@ void EuclideanCoords::drawGrid( KigPainter& p ) const
 
   // x axis
   for( int i = iMinX; i <= iMaxX; i += hStep )
-    {
-      // we skip 0 since that would look stupid... (the axes going
-      // through the 0 etc. )
-      if( i == 0 ) continue;
-      
-      p.drawText(
-		 Rect( Coordinate( i * hInterval, 0 ), hStep*hInterval, -vInterval ).normalized(),
-		 QString().setNum( i * hInterval ),
-		 AlignLeft | AlignTop
-		 );
-    };
+  {
+    // we skip 0 since that would look stupid... (the axes going
+    // through the 0 etc. )
+    if( i == 0 ) continue;
+
+    p.drawText(
+      Rect( Coordinate( i * hInterval, 0 ), hStep*hInterval, -vInterval ).normalized(),
+      QString().setNum( i * hInterval ),
+      AlignLeft | AlignTop
+      );
+  };
   // y axis...
   for ( int i = iMinY; i <= iMaxY; i += vStep )
-    {
-      if( i == 0 ) continue;
-      p.drawText ( Rect( Coordinate( 0, i * vInterval ), vStep*hInterval, vInterval ).normalized(),
-		   QString().setNum( i * vInterval ),
-		   AlignBottom | AlignLeft
-		   );
-    };
+  {
+    if( i == 0 ) continue;
+    p.drawText ( Rect( Coordinate( 0, i * vInterval ), vStep*hInterval, vInterval ).normalized(),
+                 QString().setNum( i * vInterval ),
+                 AlignBottom | AlignLeft
+      );
+  };
   // arrows on the ends of the axes...
   p.setPen( QPen( Qt::gray, 1, Qt::SolidLine ) );
   p.setBrush( QBrush( Qt::gray ) );
@@ -140,3 +141,9 @@ void EuclideanCoords::drawGrid( KigPainter& p ) const
   p.drawPolygon( a, true );
   //  p.drawLine( 0, top, 0, top - 6 );
 }
+
+QString EuclideanCoords::coordinateFormatNotice() const
+{
+  return i18n( "Enter coordinates in the following form: \"(x,y)\", where "
+               "x is the x coordinate, and y is the y coordinate." );
+}
