@@ -1,6 +1,6 @@
 /**
  This file is part of Kig, a KDE program for Interactive Geometry...
- Copyright (C) 2002  Dominique Devriese
+ Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -20,4 +20,25 @@
 
 #include "objects.h"
 
+#include "../objects/object.h"
+
+#include "screeninfo.h"
+#include "rect.h"
+#include <qrect.h>
+
 // this used to be a bit more filled up :)
+
+void Objects::calc( const ScreenInfo& r ) const
+{
+  for ( const_iterator i = begin(); i != end(); ++i )
+  {
+    (*i)->calc( r );
+  };
+}
+
+Objects Objects::with( Object* o )
+{
+  Objects os( *this );
+  os.push_back( o );
+  return os;
+}
