@@ -1,6 +1,6 @@
 /**
  This file is part of Kig, a KDE program for Interactive Geometry...
- Copyright (C) 2002  Dominique Devriese
+ Copyright (C) 2002  Dominique Devriese <devriese@kde.org>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -39,3 +39,8 @@ void KigMode::enableActions()
 KigMode::~KigMode()
 {
 }
+
+StdConstructionMode* KigMode::toStdConstructionMode()
+{
+  return 0;
+}
